@@ -103,8 +103,8 @@ void make_container(int whichtab)
   self.applet = Sysinfo_Build_Objects(whichtab);
   gtk_container_add(GTK_CONTAINER(self.vbox),self.applet);
 	
-  gtk_widget_show_all(self.applet);
-  gtk_widget_show(self.dismiss);
+  gtk_widget_show(self.applet);
+  gtk_widget_show_all(hbuttons);
 }
 
 
@@ -138,21 +138,19 @@ void main_one(int argc, char **argv)
   if (gpe_application_init (&argc, &argv) == FALSE)
     exit (1);
 
-printf("Using SHM %i\n",gdk_get_use_xshm());
-
   if (gpe_load_icons (my_icons) == FALSE)
     exit (1);
   
   initwindow();
 
   self.vbox = gtk_vbox_new(FALSE,0);
+  gtk_widget_show(self.vbox);
   gtk_container_add(GTK_CONTAINER(self.w),self.vbox);
+  gpe_set_window_icon(self.w,"icon");
+  gtk_widget_show(self.w);
 
   make_container(nrtab);
-
-  gpe_set_window_icon(self.w,"icon");
-  gtk_widget_show_all(self.w);
- 
+printf("%i\n",nrtab); 
   gtk_main();
   gtk_exit(0);
 }
