@@ -605,6 +605,7 @@ GtkWidget *Time_Build_Objects(gboolean nonroot)
   update_enabled_widgets(NULL);
   g_signal_connect_after (G_OBJECT (notebook), "switch-page",
 			G_CALLBACK (do_tabchange), NULL);
+  gtk_widget_show_all(notebook);
   
   return notebook;
 }
@@ -657,8 +658,9 @@ void Time_Save()
   if (!nonroot_mode)
   {
 	  tz = get_tz_info(par);
-		  
-	  gtk_calendar_get_date(GTK_CALENDAR(GTK_DATE_COMBO(self.cal)->cal),&year,&month,&day);
+	  year = GTK_DATE_COMBO(self.cal)->year;
+	  month = GTK_DATE_COMBO(self.cal)->month;
+	  day = GTK_DATE_COMBO(self.cal)->day;
 	  gpe_time_sel_get_time(GPE_TIME_SEL(self.tsel),&h,&m);
 	  s = 0;	 
 	  tm.tm_mday=day;
